package com.yizhi.assignment.application.feign;

import com.baomidou.mybatisplus.plugins.Page;
import com.yizhi.assignment.application.vo.AssignmentCalendarVO;
import com.yizhi.assignment.application.vo.CalendarTaskParamVo;
import com.yizhi.assignment.application.vo.apivo.*;
import com.yizhi.assignment.application.vo.entity.Assignment;
import io.swagger.annotations.ApiParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
@FeignClient(name="assignment", contextId = "AssignmentStudentClient")
public interface AssignmentStudentClient {
	
	
	@GetMapping("/remote/api/assignment/my/answer/zip")
	public String getStudentAnswerZipByAnswerId(@RequestParam(name="assignmentId")Long assignmentId,@RequestParam(name="answerId")Long answerId);
	
	
	/**
	 * 分页查询作业列表
	 * @param type
	 * @param pageNo
	 * @param pageSize
	 * @return
	 */
	@GetMapping("/remote/api/assignment/my/list")
    public Page<ApiAssignmentListResultVO> list(@RequestParam(name = "type", defaultValue = "1") int type, @RequestParam(name = "pageNo", defaultValue = "1") int pageNo, @RequestParam(name = "pageSize", defaultValue = "10") int pageSize, @RequestParam(name = "accountId") Long accountId, @RequestParam(name = "relationIds") List<Long> relationIds, @RequestParam(name = "companyId") Long companyId, @RequestParam(name = "siteId") Long siteId);
	
	
	
	/**
	 * 根据名字关键字查询
	 * @param name
	 * @param pageNo
	 * @param pageSize
	 * @return
	 */
	@GetMapping("/remote/api/assignment/my/list/search")
    public Page<ApiAssignmentListResultVO> listSearch(@RequestParam(name = "name",required=false) String name,@RequestParam(name = "pageNo", defaultValue = "1") int pageNo,@RequestParam(name = "pageSize", defaultValue = "10") int pageSize,@RequestParam(name = "accountId") Long accountId,@RequestParam(name = "relationIds") List<Long> relationIds,@RequestParam(name = "siteId") Long siteId);
	
	
	
	/**
	 * 答案列表
	 * @param assignmentId
	 * @param accountId
	 * @return
	 */
	@GetMapping("/remote/api/assignment/my/answer/list")
	public ApiAssignmentAnswerResultVo answerList(@RequestParam(name = "assignmentId") Long assignmentId,
												  @RequestParam(name = "accountId") Long accountId);
	
	
	/**
	 * 查看作业以及自己的某一份答案详细信息
	 * @param assignmentId 
	 * @return
	 */
	 @GetMapping("/remote/api/assignment/my/toAssignment")
	 public ApiAssignmentDetailsVo toAssignment(@RequestParam(name = "assignmentId") Long assignmentId, @RequestParam(name = "answerId") Long answerId, @RequestParam(name = "accountId") Long accountId);
	 
	 /**
	  * 活动用
	  * @param assignmentId
	  * @return
	  */
	 @GetMapping("/remote/api/assignment/my/toAssignmentActivity")
	 public Assignment toAssignmentActivity(@RequestParam(name = "assignmentId") Long assignmentId);
	 
	 /**
	  * 查看作业详细信息
	  * @param assignmentId
	  * @return
	  */
	 @GetMapping("/remote/api/assignment/my/getAssignment")
	 public ApiAssignmentVO getAssignment(@RequestParam(name = "assignmentId") Long assignmentId, @RequestParam(name = "accountId") Long accountId);
	
	 
	 @PostMapping("/remote/api/assignment/my/can/submit")
	 public Integer canSubmit(@RequestBody ApiAssignmentAswerVO assignmentAswerVO);
	 
	 
	 /**
	  * 作业提交
	  * @param assignmentAswerVO
	  * @return
	  */
	 @PostMapping("/remote/api/assignment/my/submit")
	 public Boolean submit(@RequestBody ApiAssignmentAswerVO assignmentAswerVO);
	 
	 
	 
	 /**
	  * 查看作业评阅
	  * @return
	  */
	 @GetMapping("/remote/api/assignment/my/suggestion/get")
	 public ApiSuggestionVo getSuggesstion(@RequestParam(name = "assignmentId") Long assignmentId,@RequestParam(name = "accountId") Long accountId);
	 
	 
	 
	 @GetMapping("/remote/api/assignment/my/list/search/others")
	 public List<ToOthersApi> listSearchOthers(
	 		@RequestParam(name = "name",required=false) String name,
			@RequestParam(name = "pageNo", defaultValue = "1") int pageNo,
			@RequestParam(name = "pageSize", defaultValue = "10") int pageSize,
			@RequestParam(name = "accountId") Long accountId,
			@RequestParam(name = "relationIds") List<Long> relationIds,
			@RequestParam(name = "siteId") Long siteId
	 );

	 
	 /**
	  * 根据id查询到这个账号下的作业个数
	  * @param accountId
	  * @return
	  */
	 @GetMapping("/remote/api/assignment/my/assignment/num")
	 public Integer getAssignmentNumByAccountId(@ApiParam(name="relationIds",value="关联ids")@RequestParam(name="relationIds",required=false)List<Long> relationIds,
			 @ApiParam(name="siteId",value="站点id")@RequestParam(name="siteId",required=true)Long siteId,
			 @ApiParam(name="accountId",value="账号id")@RequestParam(name="accountId",required=true)Long accountId);
	 
	 
	 /**
	  * 培训项目积分
	  * @param ids
	  * @return
	  */
	 @GetMapping("/remote/api/assignment/training/point")
	 public Map<String,Integer> getTrainingPoint(@RequestParam(name = "ids") List<Long> ids);

	/**
	 * 日历任务获取作业列表

	 */
	@PostMapping("/remote/api/assignment/getPageToCalendar")
	public Page<AssignmentCalendarVO> getPageToCalendar(@ApiParam("paramVo") @RequestBody CalendarTaskParamVo paramVo);
}
