package com.yizhi.application.mapper;

import java.util.Date;
import java.util.List;
import java.util.Map;

import com.yizhi.application.entity.Assignment;
import com.yizhi.assignment.application.vo.MinimbaAssignmentVO;
import com.yizhi.assignment.application.vo.MinimbaStudyRecordVO;
import com.yizhi.assignment.application.vo.MinimbaUserDetailParamVO;
import com.yizhi.assignment.application.vo.MinimbaUserDetailVO;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.session.RowBounds;
import com.baomidou.mybatisplus.mapper.BaseMapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.yizhi.assignment.application.vo.apivo.ApiListVo;
import com.yizhi.assignment.application.vo.apivo.ToOthersApi;

/**
 * <p>
 * 老师布置作业的主表 Mapper 接口
 * </p>
 *
 * @author 王飞达123
 * @since 2018-03-08
 */
public interface AssignmentMapper extends BaseMapper<Assignment> {

    /**
     * 查询已经完成的
     * 1.不可以补交：结束时间小于当前时间and未提交
     * 2.可以补交： 已经提交
     *
     * @param accountId 当前登录学员id
     * @param date      当前时间
     * @param rowBounds 分页参数
     * @return
     */
    List<ApiListVo> listFinished(@Param("accountId") Long accountId, @Param("assignmentIds") List<Long> assignmentIds, @Param("date") Date date, RowBounds rowBounds);

    /**
     * 已经完成的数量
     *
     * @param accountId
     * @param assignmentIds
     * @param date
     * @return
     */
    Integer listFinishedNum(@Param("accountId") Long accountId, @Param("assignmentIds") List<Long> assignmentIds, @Param("date") Date date);

    /**
     * 查询已经进行中的
     * 1.结束时间大于当前时间
     * 2.结束时间小于当前时间：可以补交and未提交
     *
     * @param accountId 当前登录学员id
     * @param date      当前时间
     * @param rowBounds 分页参数
     * @return
     */
    List<Assignment> listUnfinished(@Param("accountId") Long accountId, @Param("assignmentIds") List<Long> assignmentIds, @Param("date") Date date, RowBounds rowBounds);

    /**
     * 未完成的数量
     *
     * @param accountId
     * @param assignmentIds
     * @param date
     * @return
     */
    Integer listUnfinishedNum(@Param("accountId") Long accountId, @Param("assignmentIds") List<Long> assignmentIds, @Param("date") Date date);

    /**
     * 查询所有的作业
     *
     * @param name
     * @param accountId
     * @param date
     * @param rowBounds
     * @return
     */
    List<ApiListVo> listAll(@Param("name") String name, @Param("assignmentIds") List<Long> assignmentIds, RowBounds rowBounds);


    /**
     * 根据账号id查到自己账号下的作业数量
     *
     * @param accountId
     * @return
     */
    Integer selectAssignmentNumByAccountId(@Param("accountId") Long accountId);


    /**
     * 1指定范围为全平台可见  2没有被删除的作业（statues！=0）3站点
     *
     * @param siteId
     * @return
     */
    List<Long> listAssignmentBySiteIdNoDeleted(@Param("siteId") Long siteId);


    /**
     * 给门户用                                   学员端--------------2018/09/08
     *
     * @param assignmentIds
     * @return
     */
    List<ToOthersApi> listToOthersApi(@Param("assignmentIds") List<Long> assignmentIds);


    /**
     * 根据账号查出来  作业和答案提交次数
     *
     * @param accountId
     * @return
     */
    List<Long> getIsOverVO(@Param("accountId") Long accountId, @Param("siteId") Long siteId);


    List<Long> getAssignmentIdsOrdersPageLimit(@Param("assignmentIds") List<Long> assignmentIds, RowBounds rowBounds);

    List<Long> getAssignmentIdsByProjectId(@Param("projectId") Long projectId);

    boolean updateProjectMessageByAssignmentId(@Param("assignmentId") Long assignmentId);


    List<Assignment> getAssignmentListByManager(@Param("accountId") Long accountId,
                                                @Param("admin") Integer admin,
                                                @Param("name") String name,
                                                @Param("dateString") String dateString,
                                                @Param("companyId") Long companyId,
                                                @Param("siteId") Long siteId,
                                                @Param("source") Integer source,
                                                @Param("adminIds") List<Long> adminIds,
                                                Page<Assignment> page);

    /**
     * 取消作业和培训项目的关联
     *
     * @param assignmentId
     * @return
     */
    Integer delete(@Param("assignmentId") Long assignmentId);

    List<Map<String, Object>> experiencePoolList(@Param("name") String name, @Param("ids") List<Long> ids,
                                                 @Param("companyId") Long companyId, @Param("siteId") Long siteId,
                                                 Page<Map<String, Object>> page);

    /**
     * 传培训项目id集合,返回这些项目所有关联的作业该用户的总打卡次数以及总的被赞次数(加一个请求参数,需要区别是取前一天截止的数据还是实时数据)
     *
     * @param paramVO
     * @return
     */
    MinimbaUserDetailVO userDetail(@Param("param") MinimbaUserDetailParamVO paramVO, @Param("siteId") Long siteId, @Param("companyId") Long companyId, @Param("accountId") Long accountId);

    int updateNum(@Param("assignment") Assignment assignment);

    int selectCountFinishedPlan(@Param("accountId") long accountId, @Param("param") MinimbaUserDetailParamVO paramVO);

    int selectCountAllPlan(@Param("param") MinimbaUserDetailParamVO paramVO);

    List<MinimbaStudyRecordVO> getMinimbaStudyRecordVO(@Param("tpId") long tpId);

    @Select("select count(seconds) " +
            "from tp_student_activity_record " +
            "where relation_id = #{actId}")
    int selectSeconds(@Param("actId") long actId);

    @Select("select score " +
            "from tp_student_activity_record " +
            "where relation_id = #{actId} " +
            "and finished = 1 " +
            "order by finish_date desc " +
            "limit 1")
    Float selectScore(@Param("actId") long actId);

    //    @Select("SELECT " +
//            "answer.content AS content, " +
//            "answer.create_time AS submitTime, " +
//            "IFNULL(sum( thumb.is_thumb ),0) AS admireNum, " +
//            "count( `comment`.assignment_answer_id ) AS commentNum  " +
//            "FROM " +
//            "assignment_answer answer " +
//            "LEFT JOIN assignment_answer_thumb thumb ON answer.id = thumb.assignment_answer_id  " +
//            "AND thumb.is_thumb = 1 " +
//            "LEFT JOIN assignment_comment `comment` ON `comment`.assignment_answer_id = answer.id  " +
//            "LEFT JOIN assignment_answer_file `file` ON `file`.anwser_id = answer.id  "+
//            "WHERE " +
//            "answer.assignment_id = (select relation_id from tp_plan_activity where tp_plan_id = #{planId} and type = 5 LIMIT 1)   " +
//            "AND answer.deleted = 0  " +
//            "GROUP BY " +
//            "answer.id  " +
//            "ORDER BY " +
//            "answer.create_time DESC ")
    List<MinimbaAssignmentVO> getMinimbaAssignmentVO(@Param("planId") long planId, @Param("accountId") Long accountId);

    /**
     * 获取考试id
     *
     * @param planId
     * @return
     */
    Long getPlanExamId(@Param("planId") Long planId);

    List<Long> getIdsByDate(@Param("currentDate") Date currentDate, @Param("siteId") Long siteId);

    List<Assignment> getPageToCalendar(@Param("passIds") List<Long> passIds,
                                            @Param("assignmentIdsFromVisibRange") List<Long> assignmentIdsFromVisibRange,
                                            @Param("currentDate") Date currentDate,
                                            @Param("siteId") Long siteId,
                                            Page page);
    Integer getPageToCalendarNum(@Param("passIds") List<Long> passIds,
                                       @Param("assignmentIdsFromVisibRange") List<Long> assignmentIdsFromVisibRange,
                                       @Param("currentDate") Date currentDate,
                                       @Param("siteId") Long siteId);
}
